# Table of Contents

- [integration-rest-api](<./integration-rest-api.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Integration REST API](<./Integration-REST-API.md>)
  - [Overview](<./Integration-REST-API/Overview.md>)
  - [Creating a Processor](<./Integration-REST-API/Creating-a-Processor.md>)
  - [Creating a Synchronization Run](<./Integration-REST-API/Creating-a-Synchronization-Run.md>)
  - [Starting a Synchronization Run](<./Integration-REST-API/Starting-a-Synchronization-Run.md>)
  - [Canceling a Synchronization Run](<./Integration-REST-API/Canceling-a-Synchronization-Run.md>)
  - [Retrieving the Status of a Synchronization Run](<./Integration-REST-API/Retrieving-the-Status-of-a-Synchronization-Run.md>)
  - [Retrieving the Details of a Synchronisation Run](<./Integration-REST-API/Retrieving-the-Details-of-a-Synchronisation-Run.md>)
  - [Importing a Collection to Postman](<./Integration-REST-API/Importing-a-Collection-to-Postman.md>)
  - [Was this page helpful?](<./Integration-REST-API/Was-this-page-helpful.md>)
